//############################################################################
//
// EZFB ~ Linux Frame Buffer API ~
//
// by James Lehman
// james@akrobiz.com
//
// began: Feb. 2001
//
// EZFB is intended to give C programmers an easy-to-use library of functions
// for drawing points, lines and strings of characters into the Linux frame
// buffer. It also provides a means of displaying bitmap images on any portion
// of the screen and capturing the contents of any portion of the screen to
// a standard bitmap graphics file. All of this is embodied in a set of
// functions that are polymorphic with regard to the characteristics of the
// frame buffer and the bitmap files used. In other words, it makes no
// difference what the screen height or width is or what the color depth is,
// all of the function calls are the same and will have appropriate and
// predictable effects.
//
// This software is distributed in the hope that it will be useful, but
// without any warranty; without even the implied warranty of merchantability
// or fitness for a particular purpose. See the GNU General Public License
// for more details.
//
//############################################################################

#ifndef __EZFB_TTY_SWITCH_FUNCTIONS__
#define __EZFB_TTY_SWITCH_FUNCTIONS__

//############################################################################

#include "ezfb_types.h"

//############################################################################
#define ARROW_UP			0x415b1b
#define ARROW_DOWN			0x425b1b
#define ARROW_RIGHT			0x435b1b
#define ARROW_LEFT			0x445b1b
#define ESCAPE_KEY			0x1b
#define F1_KEY				0x504f1b
#define F2_KEY				0x514f1b
#define F3_KEY				0x524f1b
#define F4_KEY				0x534f1b
#define DELETE_KEY			0x7f
#define CTRL_A				0x1
#define CTRL_B				0x2
// #define CTRL_C TERMINATES PROGRAM
#define CTRL_D				0x4
#define CTRL_E				0x5
#define CTRL_F				0x6
#define CTRL_G				0x7
#define CTRL_H				0x8
#define BACKSPACE_KEY		0x8
#define CTRL_I				0x9
#define TAB_KEY				0x9
#define CTRL_J				0xa
#define ENTER_KEY			0xa
#define CTRL_K				0xb
#define CTRL_L				0xc
#define CTRL_M				0xd
#define CTRL_N				0xe
#define CTRL_O				0xf
#define CTRL_P				0x10
//#define CTRL_Q DOES NOTHING
#define CTRL_R				0x12
//#define CTRL_S SCREWS UP THE CONSOLE
#define CTRL_T				0x14
#define CTRL_U				0x15
#define CTRL_V				0x16
#define CTRL_W				0x17
#define CTRL_X				0x18
#define CTRL_Y				0x19
//#define CTRL_Z SUSPENDS THE PROGRAM

//############################################################################
int   set_tty_graphics ();
int   set_tty_text     ();
void  reset_input_mode ();
int   set_input_mode   ();
char  kb_hit           ();
int   wait_4_key       ();
int   get_key          ();
int   get_dec_int      ();
int   get_chars        (char* line);
//############################################################################
#endif

//############################################################################
//////////////////////////////////////////////////////////////////////////////
//############################################################################

